<?php
######################################################################
# Weather Magnet
# ============================================
#
# Copyright (c) 2003 by John Horne seventhseal@ibdeeming.com
# http://ibdeeming.com
#
#
# This program is free software. You can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License.
######################################################################
require_once("mainfile.php");

$module_name = basename(dirname(__FILE__));
get_lang($module_name);

require_once("modules/$module_name/wh_ini.php");
require_once("modules/$module_name/wh_utils.php");

/*******************************************************************************************************************************************/
/*                                                                                                                                         */
/* function fnCacheCleanup()                                                                                                               */
/*                                                                                                                                         */
/* This function cleans out the cache directory of old files                                                                               */
/*******************************************************************************************************************************************/

function fnCacheCleanup( $local_file_path )                                                              
{
  global $db, $prefix;
  $wh = new whini( $db, $prefix );

  if ($handle = opendir($local_file_path))
  {
    while (false !== ($file = readdir($handle)))
	{ 
      if ($file != "." && $file != "..")
	  { 
	    $now = time();
	    $age = filectime( $local_file_path.$file );
		$cachetime = $wh->getcachetimeout(); 
		if ( $now > ( $age + $cachetime ) )  // see if it's too old
		{
		  unlink( $local_file_path.$file );  // it's too old, delete it!!!
		}
      } 
    }
    closedir($handle); 
  }
}

/*******************************************************************************************************************************************/
/*                                                                                                                                         */
/* function processMETAR( $local_file )                                                                                                    */
/*                                                                                                                                         */
/* This function processes METAR data generated by NOAA.  The file passed in is the local filename on your host server.                    */
/*******************************************************************************************************************************************/

function processMETARFile( $local_file, $mini_block )
{
  $lines = "";

  if (file_exists( $local_file ) )
  {
    $handle = fopen( $local_file, "r" );
    while (!feof($handle) )
    {
      $lines .= fgets( $handle, 1024 );
    }
    fclose( $handle );

    if ($lines != "")
    {
      $return_string = processMETARLines( $lines, $mini_block );
    }
    else
    {
      $return_string = _WEATHER_NOT_AVAILABLE;
    }
  }
  else
  {
    $return_string = _WEATHER_NOT_AVAILABLE;
  }

  return( $return_string );
}

function processMETARLines( $lines, $mini_block )
{
  $return_string = weatherDateTime( $lines );
  $return_string .= weatherCurCond( $lines, $mini_block );
  

  if ($mini_block == false)
  {
    $return_string .= "<table><tr><td align=\"left\">\n";

    // get the wind speed and direction
    if ( eregi( "00000KT", $lines ) ) // look for calm first
    {
      $return_string .= "<b>Wind:</b></td><td align=\"right\">Calm<br>";
    }
    else if ( eregi( "VRB([0-9]*)KT", $lines, $buffer ) ) // look for variable wind with VRB
    {
      $wndKT = $buffer[1];
      // convert to mph
      $wndMPH = $wndKT * 1.143;
      $wndString = sprintf( "<b>Wind:</b></td><td align=\"right\">Variable at %.02f kt (%.02f mph)", $wndKT, $wndMPH );
      $return_string .= $wndString;
    }
    else if ( eregi( "([0-9]{5})KT ([0-9]{3})V([0-9]{3})", $lines, $buffer ) ) // look for variable direction with directionals
    {
      // get direction first
      $directionOne = intval( substr( $buffer[2], 0, 3 ) );
      $directionTwo = intval( substr( $buffer[3], 0, 3 ) );
      $wndKT = intval( substr( $buffer[1], 3, 2 ) );
      // convert speed to mph
      $wndMPH = $wndKT * 1.143;
    
      if ( $directionOne > 10 && $directionOne <= 35 )  // NNE
      {
        $dirOne = "NNE"; 
      }
      else if ( $directionOne > 35 && $directionOne <= 55 ) // NE
      {
        $dirOne = "NE";
      }
      else if ($directionOne > 55 && $directionOne <= 80) // ENE
      {
        $dirOne = "ENE";
      }
      else if ($directionOne > 80 && $directionOne <= 100 ) // E
      {
        $dirOne = "E";
      }
      else if ($directionOne > 100 && $directionOne <= 125 ) // ESE
      {
        $dirOne = "ESE";
      }
      else if ( $directionOne > 125 && $directionOne <= 145 ) // SE
      {
        $dirOne = "SE";
      }
      else if ($directionOne > 145 && $directionOne <= 170 ) // SSE
      {
        $dirOne = "SSE";
      }
      else if ($directionOne > 170 && $directionOne <= 190 ) // S
      {
        $dirOne = "S";
      }
      else if ($directionOne > 190 && $directionOne <= 215 ) // SSW
      {
        $dirOne = "SSW";
      }
      else if ($directionOne > 215 && $directionOne <= 235 ) // SW
      {
        $dirOne = "SW";
      }
      else if ($directionOne > 235 && $directionOne <= 260 ) // WSW
      {
        $dirOne = "WSW";
      }
      else if ( $directionOne > 260 && $directionOne <= 280 ) // W
      {
        $dirOne = "W";
      }
      else if ($directionOne > 280 && $directionOne <= 305 ) // WNW
      {
        $dirOne = "WNW";
      }
      else if ( $directionOne > 305 && $directionOne <= 325 ) // NW
      {
        $dirOne = "NW";
      }
      else if ($directionOne > 325 && $directionOne <= 350 )  // NNW
      {
        $dirOne = "NNW";
      }
      else  // N
      {
        $dirOne = "N";
      }

      if ( $directionTwo > 10 && $directionTwo <= 35 )  // NNE
      {
        $dirTwo = "NNE"; 
      }
      else if ( $directionTwo > 35 && $directionTwo <= 55 ) // NE
      {
        $dirTwo = "NE";
      }
      else if ($directionTwo > 55 && $directionTwo <= 80) // ENE
      {
        $dirTwo = "ENE";
      }
      else if ($directionTwo > 80 && $directionTwo <= 100 ) // E
      {
        $dirTwo = "E";
      }
      else if ($directionTwo > 100 && $directionTwo <= 125 ) // ESE
      {
        $dirTwo = "ESE";
      }
      else if ( $directionTwo > 125 && $directionTwo <= 145 ) // SE
      {
        $dirTwo = "SE";
      }    
      else if ($directionTwo > 145 && $directionTwo <= 170 ) // SSE
      {
        $dirTwo = "SSE";
      }
      else if ($directionTwo > 170 && $directionTwo <= 190 ) // S
      {
        $dirTwo = "S";
      }
      else if ($directionTwo > 190 && $directionTwo <= 215 ) // SSW
      {
        $dirTwo = "SSW";
      }
      else if ($directionTwo > 215 && $directionTwo <= 235 ) // SW
      {
        $dirTwo = "SW";
      }
      else if ($directionTwo > 235 && $directionTwo <= 260 ) // WSW
      {
        $dirTwo = "WSW";
      }
      else if ( $directionTwo > 260 && $directionTwo <= 280 ) // W
      {
        $dirTwo = "W";
      }
      else if ($directionTwo > 280 && $directionTwo <= 305 ) // WNW
      {
        $dirTwo = "WNW";
      }
      else if ( $directionTwo > 305 && $directionTwo <= 325 ) // NW
      {
        $dirTwo = "NW";
      }
      else if ($directionTwo > 325 && $directionTwo <= 350 )  // NNW
      {
        $dirTwo = "NNW";
      }
      else  // N
      {
        $dirTwo = "N";
      }
      $return_string .= sprintf( "<b>Wind:</b></td><td align=\"right\">Variable from the %s to the %s at %.02f kt (%.02f mph)", $dirOne, $dirTwo, $wndKT, $wndMPH );
    }
    else if (eregi( "([0-9]{5})KT G([0-9]{2})KT ", $lines, $buffer ) )   // another form of gusting wind
    {
      // get direction first
      $direction = intval( substr( $buffer[1], 0, 3 ) );
      $wndKT = intval( substr( $buffer[1], 3, 2 ) );
      $wndGKT = intval( substr( $buffer[2], 0, 2 ) );
      // convert speed to mph
      $wndMPH = $wndKT * 1.143;
      $wndGMPH = $wndGKT * 1.143;

      if ( $direction > 10 && $direction <= 35 )  // NNE
      {
        $dir = "NNE"; 
      }
      else if ( $direction > 35 && $direction <= 55 ) // NE
      {
        $dir = "NE";
      }
      else if ($direction > 55 && $direction <= 80) // ENE
      {
        $dir = "ENE";
      }
      else if ($direction > 80 && $direction <= 100 ) // E
      {
        $dir = "E";
      }
      else if ($direction > 100 && $direction <= 125 ) // ESE
      {
        $dir = "ESE";
      }
      else if ( $direction > 125 && $direction <= 145 ) // SE
      {
        $dir = "SE";
      }
      else if ($direction > 145 && $direction <= 170 ) // SSE
      {
        $dir = "SSE";
      }
      else if ($direction > 170 && $direction <= 190 ) // S
      {
        $dir = "S";
      }
      else if ($direction > 190 && $direction <= 215 ) // SSW
      {
        $dir = "SSW";
      }
      else if ($direction > 215 && $direction <= 235 ) // SW
      {
        $dir = "SW";
      }
      else if ($direction > 235 && $direction <= 260 ) // WSW
      {
        $dir = "WSW";
      }
      else if ( $direction > 260 && $direction <= 280 ) // W
      {
        $dir = "W";
      }
      else if ($direction > 280 && $direction <= 305 ) // WNW
      {
        $dir = "WNW";
      }
      else if ( $direction > 305 && $direction <= 325 ) // NW
      {
        $dir = "NW";
      }
      else if ($direction > 325 && $direction <= 350 )  // NNW
      {
        $dir = "NNW";
      }
      else  // N
      {
        $dir = "N";
      }
    
      $return_string .= sprintf( "<b>Wind:</b></td><td align=\"right\">From the %s at %.02f kt (%.02f mph) gusting to %.02f kt (%.02f mph)", $dir, $wndKT, $wndMPH, $wndGKT, $wndGMPH );
    }
    else if ( eregi( "([0-9]{5})KT ", $lines, $buffer ) )  // just look for standard wind measurement
    {
    // get direction first
      $direction = intval( substr( $buffer[1], 0, 3 ) );
      $wndKT = intval( substr( $buffer[1], 3, 2 ) );
    // convert speed to mph
      $wndMPH = $wndKT * 1.143;

      if ( $direction > 10 && $direction <= 35 )  // NNE
      {
        $dir = "NNE"; 
      }
      else if ( $direction > 35 && $direction <= 55 ) // NE
      {
        $dir = "NE";
      }
      else if ($direction > 55 && $direction <= 80) // ENE
      {
        $dir = "ENE";
      }
      else if ($direction > 80 && $direction <= 100 ) // E
      {
        $dir = "E";
      }
      else if ($direction > 100 && $direction <= 125 ) // ESE
      {
        $dir = "ESE";
      }
      else if ( $direction > 125 && $direction <= 145 ) // SE
      {
        $dir = "SE";
      }
      else if ($direction > 145 && $direction <= 170 ) // SSE
      {
        $dir = "SSE";
      }
      else if ($direction > 170 && $direction <= 190 ) // S
      {
        $dir = "S";
      }
      else if ($direction > 190 && $direction <= 215 ) // SSW
      {
        $dir = "SSW";
      }
      else if ($direction > 215 && $direction <= 235 ) // SW
      {
        $dir = "SW";
      }
      else if ($direction > 235 && $direction <= 260 ) // WSW
      {
        $dir = "WSW";
      }
      else if ( $direction > 260 && $direction <= 280 ) // W
      {
        $dir = "W";
      }
      else if ($direction > 280 && $direction <= 305 ) // WNW
      {
        $dir = "WNW";
      }
      else if ( $direction > 305 && $direction <= 325 ) // NW
      {
        $dir = "NW";
      }
      else if ($direction > 325 && $direction <= 350 )  // NNW
      {
        $dir = "NNW";
      }
      else  // N
      {
        $dir = "N";
      }

      $return_string .= sprintf( "<b>Wind:</b></td><td align=\"right\">From the %s at %.02f kt (%.02f mph)", $dir, $wndKT, $wndMPH );
    }
    else if ( eregi( "([0-9]{5}G[0-9]{2})KT ", $lines, $buffer ) )  // just look for gusting wind measurement
    {
    // get direction first
      $direction = intval( substr( $buffer[1], 0, 3 ) );
      $wndKT = intval( substr( $buffer[1], 3, 2 ) );
      $wndGKT = intval( substr( $buffer[1], 6, 2 ) );
    // convert speed to mph
      $wndMPH = $wndKT * 1.143;
      $wndGMPH = $wndGKT * 1.143;

      if ( $direction > 10 && $direction <= 35 )  // NNE
      {
        $dir = "NNE"; 
      }
      else if ( $direction > 35 && $direction <= 55 ) // NE
      {
        $dir = "NE";
      }
      else if ($direction > 55 && $direction <= 80) // ENE
      {
        $dir = "ENE";
      }
      else if ($direction > 80 && $direction <= 100 ) // E
      {
        $dir = "E";
      }
      else if ($direction > 100 && $direction <= 125 ) // ESE
      {
        $dir = "ESE";
      }
      else if ( $direction > 125 && $direction <= 145 ) // SE
      {
        $dir = "SE";
      }
      else if ($direction > 145 && $direction <= 170 ) // SSE
      {
        $dir = "SSE";
      }
      else if ($direction > 170 && $direction <= 190 ) // S
      {
        $dir = "S";
      }
      else if ($direction > 190 && $direction <= 215 ) // SSW
      {
        $dir = "SSW";
      }
      else if ($direction > 215 && $direction <= 235 ) // SW
      {
        $dir = "SW";
      }
      else if ($direction > 235 && $direction <= 260 ) // WSW
      {
        $dir = "WSW";
      }
      else if ( $direction > 260 && $direction <= 280 ) // W
      {
        $dir = "W";
      }
      else if ($direction > 280 && $directin <= 305 ) // WNW
      {
        $dir = "WNW";
      }
      else if ( $direction > 305 && $direciton <= 325 ) // NW
      {
        $dir = "NW";
      }
      else if ($direction > 325 && $direction <= 350 )  // NNW
      {
        $dir = "NNW";
      }
      else  // N
      {
        $dir = "N";
      }

      $return_string .= sprintf( "<b>Wind:</b></td><td align=\"right\">From the %s at %.02f kt (%.02f mph) gusting to %.02f kt (%.02f mph)", $dir, $wndKT, $wndMPH, $wndGKT, $wndGMPH );
    }
    else
    {
      $return_string .= "</td><td>";
    }

    $return_string .= "</td></tr>\n<tr><td align=\"left\">";

  // get barometric pressure
    if ( eregi( " A([0-9]{4})", $lines, $buffer ) ) 
    {
      $bpIn = substr( $buffer[1], 0, 4 );
      $bpIn /= 100.0;
    // figure out hPa
      $bphPa = ( $bpIn * 3386.389 ) / 100.0;

      $bpString = sprintf( "<b>Pres.:</b></td><td align=\"right\">%.02f in. (%.02f hPa)", $bpIn, $bphPa );
      $return_string .= $bpString;
    }
    else if (eregi( " Q([0-9]{4})", $lines, $buffer ) ) 
    {
      $bphPa = substr( $buffer[1], 0, 4 );
    // figure out in.
      $bpIn = ( $bphPa * 100.0 ) / 3386.389;

      $bpString = sprintf( "<b>Pres.:</b></td><td align=\"right\">%.2f in. (%.2f hPa)", $bpIn, $bphPa );
      $return_string .= $bpString;
    }
    else
    {
      $return_string .= "</td><td>";
    }


    $return_string .= "</td></tr>\n<tr><td align=\"left\">";

  // get visibility info
    if ( eregi( "(M [0-9]/[0-9]*)SM ", $lines, $buffer ) ) 
    {
      // found the M - so a number will follow, and the string should be less than x miles
      $visSM = substr( $buffer[1], 1 );
      $visString = sprintf( "<b>Visibility:</b></td><td align=\"right\">Less than %s miles", $visSM );
      $return_string .= $visString;
    }
    else if ( eregi( "([0-9] [0-9]/[0-9])SM ", $lines, $buffer ) ) // just take the string and format out...
    {
      $visSM = substr( $buffer[1], 0 );
      $visString = sprintf( "<b>Visibility:</b></td><td align=\"right\">%s miles", $visSM );
      $return_string .= $visString;
    }
    else if ( eregi( "([0-9]*)SM ", $lines, $buffer ) ) // just take the string and format out...
    {
      $visSM = substr( $buffer[1], 0 );
      $visString = sprintf( "<b>Visibility:</b></td><td align=\"right\">%s miles", $visSM );
      $return_string .= $visString;
    }
    else
    {
      $return_string .= "</td><td>";
    }

    $return_string .= "</td></tr></table>";
  }

  return $return_string;
}

function weatherDateTime( $lines )
{
  $return_string = "";
  // get the date and time string
  if ( eregi( "([0-9]*)Z", $lines, $buffer ) )
  {
    $day = substr( $buffer[1], 0, 2 );
    $return_string .= "<table><tr><td>"._REPORTED_ON."<br>".date("F")."&nbsp;".$day.",&nbsp;".date("Y")."&nbsp;";
    $zhourtime = substr( $buffer[1], 2, 2 );
    $zmintime = substr( $buffer[1], 4, 2 );
    $ztime = gmmktime( $zhourtime, $zmintime );
    $formatted = strftime("%H:%M", $ztime);
    $return_string .= "at ".$formatted."</td></tr></table>";
  }

  return $return_string;
}

function weatherCurCond( $lines, $mini_block )
{
  global $db, $prefix;
  $wh = new whini( $db, $prefix );
  $wimages_loc = "modules/WeatherHarvest/images/set".$wh->getimageset()."/";
  $lines = strchr( $lines, ' ' );

  // figure out the time of day
  $timeofday = localtime( time(), 1 );
  if ( $timeofday["tm_hour"] >= 6 && $timeofday["tm_hour"] <= 18 )
  {
    $isDayTime = true;
  }
  else
  {
    $isDayTime = false;
  }
  
  $w_image = "-.gif";
  
  // look for the cloud condition
  $cloudCond = "";
  if (eregi( "OVC", $lines ) ) 
  {
    $cloudCond = "Overcast";
	$w_image = "26.gif";
  }
  else if (eregi("BKN", $lines ) ) 
  {
    $cloudCond = "Mostly Cloudy";
	if ( $isDayTime == true )
	{
	  $w_image = "28.gif";
	}
	else
	{
	  $w_image = "27.gif";
	}  
  }
  else if (eregi( "SCT", $lines ) ) 
  {
    $cloudCond = "Partly Cloudy";
	if ( $isDayTime == true )
	{
	  $w_image = "30.gif";
	}
	else
	{
	  $w_image = "29.gif";
	}  
  }
  else if (eregi( "FEW", $lines ) ) 
  {
    $cloudCond = "Mostly Clear";
	if ( $isDayTime == true )
	{
	  $w_image = "34.gif";
	}
	else
	{
	  $w_image = "33.gif";
	}  
  }
  else if (eregi( "CLR", $lines ) || eregi( "SKC", $lines ) )
  {
    $cloudCond = "Clear";
	if ( $isDayTime == true )
	{
	  $w_image = "32.gif";
	}
	else
	{
	  $w_image = "31.gif";
	}  
  }

  // look for the weather condition
  // look for intensity
  $intensity = "";

  if ( eregi( " \+", $lines ) )  // + = heavy
  {
    $intensity = "Heavy";
  }
  else if ( eregi( " -", $lines ) ) // - = light
  {
    $intensity = "Light";
  }
  else if ( eregi( " VC", $lines ) )  // VC = vicinity
  {
    $intensity = "In the vicinity";
  }
  
  // get the descriptor
  $descriptor = "";
  if ( eregi( "MI", $lines ) )
  {
    $descriptor = "shallow";
  }
  else if (eregi( "PR", $lines ) ) 
  {
    $descriptor = "partial";
  }
  else if (eregi( "BC", $lines ) ) 
  {
    $descriptor = "patches";
  }
  else if (eregi( "DR", $lines ) ) 
  {
    $descriptor = "drifting";
  }
  else if (eregi( "BL", $lines ) ) 
  {
    $descriptor = "blowing";
  }
  else if (eregi( "SH ", $lines ) ) 
  {
    $descriptor = "showers";
  }
  else if (eregi( "TS ", $lines ) )
  {
    $descriptor = "thunderstorms";
  }
  else if (eregi( "FZ", $lines ) )
  {
    $descriptor = "freezing";
  }

  // get the precipitation
  $precipitation = "";
  if (eregi( "DZ", $lines ) ) 
  {
    $precipitation = "drizzle";
	$w_image = "12.gif";
  }
  else if (eregi( "RA ", $lines ) ) 
  {
    $precipitation = "rain";
	$w_image = "12.gif";
  }
  else if (eregi( "SN ", $lines ) ) 
  {
    $precipitation = "snow";
	$w_image = "14.gif";
  }                 
  else if (eregi( "SG ", $lines ) ) 
  {
    $precipitation = "snow grains";
	$w_image = "8.gif";
  }
  else if (eregi( "IC ", $lines ) ) 
  {
    $precipitation = "ice crystals";
	$w_image = "10.gif";
  }
  else if (eregi( "PL ", $lines ) ) 
  {
    $precipitation = "ice pellets";
	$w_image = "11.gif";
  }
  else if (eregi( "GR ", $lines ) ) 
  {
    $precipitation = "hail";
	$w_image = "11.gif";
  }
  else if (eregi( "GS ", $lines ) ) 
  {
    $precipitation = "small ice or hail";
	$w_image = "6.gif";
  }
  else if (eregi( "UP ", $lines ) ) 
  {
    $precipitation = "unknown";
  }

  // get obscuration
  $obscuration = "";
  if (eregi( " BR ", $lines ) ) 
  {
    $obscuration = "mist";
	$w_image = "12.gif";
  }
  else if (eregi( " FG ", $lines ) ) 
  {
    $obscuration = "fog";
	$w_image = "20.gif";
  }
  else if (eregi( " FU ", $lines ) ) 
  {
    $obscuration = "smoke";
	$w_image = "22.gif";
  }
  else if (eregi( " VA ", $lines ) ) 
  {
    $obscuration = "volcanic ash";
	$w_image = "22.gif";
  }
  else if (eregi( " DU ", $lines ) ) 
  {
    $obscuration = "widespread dust";
	$w_image = "19.gif";
  }
  else if (eregi( " SA ", $lines ) ) 
  {
    $obscuration = "sand";
	$w_image = "19.gif";
  }
  else if (eregi( " HZ ", $lines ) ) 
  {
    $obscuration = "haze";
	$w_image = "21.gif";
  }
  else if (eregi( " PY ", $lines ) ) 
  {
    $obscuration = "spray";
	$w_image = "24.gif";
  }

  // get other
  $other = "";
  if (eregi( " PO ", $lines ) ) 
  {
    $other = "well developed Dust/Sand Storm";
	$w_image = "19.gif";
  }
  else if (eregi( " SQ ", $lines ) ) 
  {
    $other = "squalls";
	$w_image = "24.gif";
  }
  else if (eregi( " FC ", $lines ) ) 
  {
    $other = "tornado, funnel cloud or waterspout";
  }
  else if (eregi( " SS ", $lines ) ) 
  {
    $other = "sandstorm";
	$w_image = "19.gif";
  }
  else if (eregi( " DS ", $lines ) ) 
  {
    $other = "duststorm";
	$w_image = "19.gif";
  }
  
  $return_string = "";
  
  // get the temperature and dew point
  if ( eregi( " T([0-9]{8})", $lines, $buffer ) )
  {
    $negtempC = substr( $buffer[1], 0, 1 );
    $tempC = substr( $buffer[1], 1, 3 );
    $negdewC = substr( $buffer[1], 4, 1 );
    $dewC = substr( $buffer[1], 5, 3 );

    if ( $negtempC != 0 )
    {
      $tempC *= (-1.0);
    }

    $tempC /= 10.0;

    if ( $negdewC != 0 )
    {
      $dewC *= (-1.0);
    }

    $dewC /= 10.0;

  // C to F conversion
    $tempF = ( $tempC * 1.8 ) + 32.0;
    $dewF = ( $dewC * 1.8 ) + 32.0;

  // figure out relative humidity
    $satvapPres = 6.11 * pow( 10,((7.5*$tempC/(237.7+$tempC))));//saturation vapor pressure
    $actvapPres = 6.11 * pow( 10,((7.5*$dewC/(237.7+$dewC))));//actual vapor pressure
    $relHumidity = ($actvapPres / $satvapPres )* 100;//relative humidity
  }
  else if ( eregi( " ([0-9]{2})/([0-9]{2}) ", $lines, $buffer ) )
  { 
    $tempC = $buffer[1];
    $dewC = $buffer[2];

  // C to F conversion
    $tempF = ( $tempC * 1.8 ) + 32.0;
    $dewF = ( $dewC * 1.8 ) + 32.0;

  // figure out relative humidity
    $satvapPres = 6.11 * pow( 10,((7.5*$tempC/(237.7+$tempC))));//saturation vapor pressure
    $actvapPres = 6.11 * pow( 10,((7.5*$dewC/(237.7+$dewC))));//actual vapor pressure
    $relHumidity = ($actvapPres / $satvapPres )* 100;//relative humidity
  }
  else if (eregi( " ([0-9]{2})/M([0-9]{2})", $lines, $buffer ) ) 
  {
    $tempC = $buffer[1];
    $dewC = 0.0 - intval($buffer[2]);

    // C to F conversion
    $tempF = ( $tempC * 1.8 ) + 32.0;
    $dewF = ( $dewC * 1.8 ) + 32.0;

    // figure out relative humidity
    $satvapPres = 6.11 * pow( 10,((7.5*$tempC/(237.7+$tempC))));//saturation vapor pressure
    $actvapPres = 6.11 * pow( 10,((7.5*$dewC/(237.7+$dewC))));//actual vapor pressure
    $relHumidity = ($actvapPres / $satvapPres )* 100;//relative humidity
  }
  else if (eregi( " M([0-9]{2})/M([0-9]{2})", $lines, $buffer ) )  // both are negative
  {
    $tempC = 0.0 - intval($buffer[1]);
    $dewC = 0.0 - intval($buffer[2]);

    // C to F conversion
    $tempF = ( $tempC * 1.8 ) + 32.0;
    $dewF = ( $dewC * 1.8 ) + 32.0;

    // figure out relative humidity
    $satvapPres = 6.11 * pow( 10,((7.5*$tempC/(237.7+$tempC))));//saturation vapor pressure
    $actvapPres = 6.11 * pow( 10,((7.5*$dewC/(237.7+$dewC))));//actual vapor pressure
    $relHumidity = ($actvapPres / $satvapPres )* 100;//relative humidity
  }

  $tempString = sprintf( "%.02f&deg;C (%.02f&deg;F)<br>", $tempC, $tempF );
  $dewString = sprintf( "<tr><td align=\"left\"><b>Dew Point:</b></td><td align=\"right\">%.02f&deg;C (%.02f&deg;F)</td></tr>", $dewC, $dewF );
  $rhString = sprintf( "<tr><td align=\"left\"><b>Humidity:</b></td><td align=\"right\">%.02f%s</td></tr>", $relHumidity, "%" );

  $return_string .= sprintf( "<table><tr><td align=\"center\"><img src='%s%s'>", $wimages_loc, $w_image );
 
  // put reports together and return
  if ( $cloudCond != "" ) 
  {
    $return_string .= sprintf( "<br><b>%s</b></td>", $cloudCond );
  }
  else
  {
    $return_string .= "</td>";
  }

  if ( $tempString != "" )
  {
    $return_string .= sprintf( "<td align=\"center\"><font class=\"title\">%s</font>", $tempString );
  }
  else
  {
    $return_string .= "<td>&nbsp;";
  }

  $return_string .= "</td></tr>\n";

  if ( $intensity != "" || $descriptor != "" || $precipitation != "" || $obscuration != "" || $other != "" )
  {
    $return_string .= "<tr><td colspan='2'><b>Weather : </b>";

    if ( $intensity != "" || $descriptor != "" || $precipitation != "" ) 
    {
      $return_string .= sprintf( "%s %s %s", $intensity, $precipitation, $descriptor );

      if ( $obscuration != "" ) 
      {
        $return_string .= sprintf( " / %s", $obscuration );
      }
    }
    else if ( $obscuration != "" ) 
    {
      $return_string .= sprintf( "%s", $obscuration );
    }
    else if ( $other != "" ) 
    {
      $return_string .= sprintf( "%s", $other );
    }
    $return_string .= "</td></tr>\n";
  }

  $return_string .= "</table>\n";
  if ($mini_block == false)
  {
    $return_string .= "<table>".$dewString.$rhString."</table>";
  }

  return $return_string;
}

?>